
create table Site(
	SiteID nvarchar(255) StartsWith UploadPA primary key,
	SiteCity nvarchar(255) NotEmpty,
	SiteState nvarchar(255) NotEmpty,
	SiteZipCode nvarchar(255) NotEmpty,
	Residential_Flag bit DefaultFalse,
	NAICSCode nvarchar(255));

create table ProgramCost(
	PrgID nvarchar(255) CedarsValueList PrgID ForeignKey Program NotEmpty,
	PrgYear nvarchar(4) NotEmpty,
	ClaimYearQuarter CedarsYearQuarter NotEmpty,
	AdminCostsOverheadAndGA numeric NotEmpty,
	AdminCostsOther numeric NotEmpty,
	MarketingOutreach numeric NotEmpty,
	DIActivity numeric NotEmpty,
	DIInstallation numeric NotEmpty,
	DIHardwareAndMaterials numeric NotEmpty,
	DIRebateAndInspection numeric NotEmpty,
	EMV numeric NotEmpty,
	UserInputIncentive numeric NotEmpty,
	OnBillFinancing numeric NotEmpty,
	CostsRecoveredFromOtherSources numeric NotEmpty,
	PA nvarchar(255) CedarsValueList PA NotEmpty,
	primary key (PrgID, PrgYear));

create table dbo.CustomMeasure(
	ClaimID nvarchar(255) primary key,
	MeasCode nvarchar(255),
	MeasAppType nvarchar(255) CedarsValueList MeasAppType NotEmpty,
	MeasDescription nvarchar(255) NotEmpty,
	UseCategory nvarchar(255) CedarsValueList UseCategory NotEmpty,
	UseSubCategory nvarchar(255) CedarsValueList UseSubCategory NotEmpty,
	TechGroup nvarchar(255) CedarsValueList TechGroup NotEmpty,
	TechType nvarchar(255) CedarsValueList TechType NotEmpty,
	UnitkW1stBaseline numeric NotEmpty,
	UnitkWh1stBaseline numeric NotEmpty,
	UnitTherm1stBaseline numeric NotEmpty,
	UnitkW2ndBaseline numeric NotEmpty,
	UnitkWh2ndBaseline numeric NotEmpty,
	UnitTherm2ndBaseline numeric NotEmpty,
	EUL_Yrs numeric CedarsNumRange [0, 30] NotEmpty,
	RUL_Yrs numeric CedarsNumRange [0, 30] NotEmpty,
	RealizationRatekW numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRatekWh numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRateTherm numeric CedarsNumRange (0, 2] NotEmpty,
	InstallationRatekW numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRatekWh numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRateTherm numeric CedarsNumRange (0, 1] NotEmpty,
	Revised_Flag bit DefaultFalse,
	PreDesc nvarchar(1024),
	StdDesc nvarchar(1024),
	MeasInflation numeric CedarsNumRange [0, 1],
	Comments nvarchar(255));

create table dbo.DeemedMeasure(
	ClaimID nvarchar(255) primary key,
	MeasCode nvarchar(255) NotEmpty,
	MeasAppType nvarchar(255) CedarsValueList MeasAppType NotEmpty,
	MeasDescription nvarchar(1024) NotEmpty,
	UnitkW1stBaseline numeric NotEmpty,
	UnitkWh1stBaseline numeric NotEmpty,
	UnitTherm1stBaseline numeric NotEmpty,
	UnitkW2ndBaseline numeric NotEmpty,
	UnitkWh2ndBaseline numeric NotEmpty,
	UnitTherm2ndBaseline numeric NotEmpty,
	EUL_Yrs numeric CedarsNumRange [0, 30] NotEmpty,
	RUL_Yrs numeric CedarsNumRange [0, 30] NotEmpty,
	RealizationRatekW numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRatekWh numeric CedarsNumRange (0, 2] NotEmpty,
	RealizationRateTherm numeric CedarsNumRange (0, 2] NotEmpty,
	InstallationRatekW numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRatekWh numeric CedarsNumRange (0, 1] NotEmpty,
	InstallationRateTherm numeric CedarsNumRange (0, 1] NotEmpty,
	Revised_Flag bit DefaultFalse,
	Comments nvarchar(255),
	SourceDesc nvarchar(100) CedarsValueList SourceDesc NotEmpty,
	Version nvarchar(50) CedarsValueList Version NotEmpty,
	DeliveryType nvarchar(20) CedarsValueList DeliveryType NotEmpty,
	StartDate CedarsDate NotEmpty,
	MeasQualifier nvarchar(50),
	MeasureID nvarchar(100) NotEmpty,
	EnergyImpactID nvarchar(100) NotEmpty,
	GSIA_ID nvarchar(50) CedarsValueList GSIA NotEmpty,
	NTG_ID nvarchar(50) CedarsValueList NTG NotEmpty,
	EUL_ID nvarchar(100) CedarsValueList EUL NotEmpty,
	RUL_ID nvarchar(100) CedarsValueList EUL,
	MeasCostID nvarchar(100) NotEmpty,
	StdCostID nvarchar(50),
	UseCategory nvarchar(50) CedarsValueList UseCategory NotEmpty,
	UseSubCategory nvarchar(50) CedarsValueList UseSubCategory NotEmpty,
	TechGroup nvarchar(50) CedarsValueList TechGroup NotEmpty,
	TechType nvarchar(50) CedarsValueList TechType NotEmpty,
	IETableName nvarchar(255),
	MeasTechID nvarchar(255),
	LaborRate nvarchar(255) CedarsValueList LaborRate,
	LocCostAdj nvarchar(255) CedarsValueList LocCostAdj NotEmpty,
	PreDesc nvarchar(1024),
	StdDesc nvarchar(1024),
	MeasImpactCalcType nvarchar(50) CedarsValueList MeasImpactCalcType NotEmpty,
  MeasInflation numeric CedarsNumRange [0, 1]);

create table Claim(
	ClaimID nvarchar(255) StartsWith UploadPA-YYYY primary key,
	SiteID nvarchar(255) references Site,
	PrgID nvarchar(255) ForeignKey Program CedarsValueList PrgID NotEmpty,
	ImplementationPA nvarchar(255) CedarsValueList PA,
	ImplementationID nvarchar(255),
	BldgType nvarchar(255) NotEmpty CedarsValueList BldgType,
	BldgLoc nvarchar(255) CedarsValueList BldgLoc NotEmpty,
	BldgVint nvarchar(255) CedarsValueList BldgVint NotEmpty,
	BldgHVAC nvarchar(255) CedarsValueList BldgHVAC NotEmpty,
	NormUnit nvarchar(255) CedarsValueList NormUnit NotEmpty,
	Sector nvarchar(255) NotEmpty CedarsValueList Sector,
	MeasAppType nvarchar(255) CedarsValueList MeasAppType NotEmpty,
	MeasImpactType nvarchar(50) CedarsValueList MeasImpactType NotEmpty,
	DeliveryType nvarchar(20) CedarsValueList DeliveryType NotEmpty,
	PrgElement nvarchar(255),
	ProjectID nvarchar(255),
	ProjectDescription nvarchar(500),
	NAICSBldgType nvarchar(255),
	E3TargetSector nvarchar(255),
	E3MeaElecEndUseShape nvarchar(255),
	E3GasSector nvarchar(255) CedarsValueList E3GasSector,
	E3GasSavProfile nvarchar(255) CedarsValueList E3GasSavProfile,
	E3ClimateZone nvarchar(255) CedarsValueList E3ClimateZone NotEmpty,
	NumUnits numeric NotEmpty,
	InstalledNumUnits numeric,
	InstalledNormUnit nvarchar(255) CedarsValueList NormUnit,
	CombustionType nvarchar(255) CedarsValueList CombustionType,
	NTGRkW numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTGRkWh numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTGRTherm numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTGRCost numeric CedarsNumRange (0, 1.5] NotEmpty,
	NTG_ID nvarchar(50) CedarsValueList NTG,
	TotalFirstYearGrosskW numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalFirstYearGrosskWh numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalFirstYearGrossTherm numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalFirstYearNetkW numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalFirstYearNetkWh numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalFirstYearNetTherm numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalLifecycleGrosskW numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalLifecycleGrosskWh numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalLifecycleGrossTherm numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalLifecycleNetkW numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalLifecycleNetkWh numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalLifecycleNetTherm numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalGrossMeasureCost numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalGrossMeasureCost_ER numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	TotalGrossIncentive numeric MarginsOfWarningAndError (0.01, 0.1) NotEmpty,
	UnitEndUserRebate numeric,
	UnitIncentiveToOthers numeric,
	UnitDirectInstallLab numeric,
	UnitDirectInstallMat numeric,
	UnitMeaCost1stBaseline numeric WarningCedarsNumRange [0, ) NotEmpty,
	UnitMeaCost2ndBaseline numeric CedarsNumRange [0, ) NotEmpty,
	WhySavingsZeroed nvarchar(255),
	WhyCostsZeroed nvarchar(255),
	PartialPaymentPercent numeric CedarsNumRange [0, 1],
	PartialPaymentFinal_Flag bit DefaultFalse,
	Upstream_Flag bit DefaultFalse,
	Residential_Flag bit DefaultFalse,
	EUC_Flag bit DefaultFalse,
	LGP_Flag bit DefaultFalse,
	REN_Flag bit DefaultFalse,
	OBF_Flag bit DefaultFalse,
	Prop39_Flag bit DefaultFalse,
	WaterOnly_Flag bit DefaultFalse,
	PublicK_12_Flag bit DefaultFalse,
	SchoolIdentifier nvarchar(255),
	FundingCycle CedarsFundingCycle NotEmpty,
	FinancingPrgID nvarchar(255) CedarsValueList PrgID,
	ClaimYearQuarter CedarsYearQuarter NotEmpty,
	ApplicationCode nvarchar(255),
	ApplicationDate WarningCedarsDate NotEmpty,
	InstallationDate CedarsDate NotEmpty,
	PaidDate CedarsDate,
	CustomerAgreementDate CedarsDate,
	ProjectCompletionDate CedarsDate NotEmpty,
	AuthorizedSignatureDate WarningCedarsDate,
	MarketEffectsBenefits numeric CedarsNumRange (0, 1],
	MarketEffectsCosts numeric CedarsNumRange (0, 1],
	RateScheduleElec nvarchar(255) CedarsValueList RateScheduleElec,
	RateScheduleGas nvarchar(255) CedarsValueList RateScheduleGas,
	Comments nvarchar(255));

create table ContactClaim(
	ClaimID nvarchar(255) references Claim NotEmpty,
	ContactID nvarchar(255) StartsWith UploadPA NotEmpty,
	primary key (ContactID, ClaimID));

create table WaterMeasure(
	ClaimID nvarchar(255) primary key,
	WaterMeasCode nvarchar(255) NotEmpty,
	SavingsProfile nvarchar(255) NotEmpty,
	HydrologicRegion nvarchar(255) NotEmpty,
	Sector nvarchar(255) NotEmpty,
	WaterUse nvarchar(255) NotEmpty,
	Gallons numeric NotEmpty,
	AvgAnnualIOUkWh numeric NotEmpty,
	AvgAnnualNonIOUkWh numeric NotEmpty,
	AvgAnnualTherm numeric NotEmpty,
	SourceDesc nvarchar(100) CedarsValueList SourceDesc NotEmpty);

